#
# spec file for package libservicelog
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libservicelog-1_1-1
%if 0%{?suse_version} < 1500
%global system_user_pkg 0
%else
%global system_user_pkg 1
%endif
Name:           libservicelog
Version:        1.1.19
Release:        3.3
Summary:        Servicelog Database and Library
License:        LGPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/power-ras/libservicelog/
#Git-Clone:	https://github.com/power-ras/libservicelog.git
#Git-Web:	https://github.com/power-ras/libservicelog/
Source0:        https://github.com/power-ras/libservicelog/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Source2:        libservicelog-rpmlintrc
Source3:        system-group-service.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  librtas-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  sqlite3-devel
ExclusiveArch:  ppc ppc64 ppc64le
%if %{system_user_pkg}
Requires(pre):  sysuser-tools
%else
Requires(pre):  %{_sbindir}/groupadd
%endif

%description
The libservicelog package contains a library to create and maintain a
database for storing events related to system service. This database
allows for the logging of serviceable and informational events, and for
the logging of service procedures that have been performed upon the
system.

%package -n %{lname}
Summary:        Servicelog Database and Library
Group:          System/Libraries
Requires:       %{name}

%description -n %{lname}
The libservicelog package contains a library to create and maintain a
database for storing events related to system service. This database
allows for the logging of serviceable and informational events, and for
the logging of service procedures that have been performed upon the
system.

%package        devel
Summary:        Development files for libservicelog
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       glibc-devel
Requires:       sqlite3-devel

%description    devel
Header files for building with libservicelog.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure --disable-static
make %{?_smp_mflags}
%if %{system_user_pkg}
%sysusers_generate_pre %{SOURCE3} libservicelog system-group-service.conf
%else
cat > libservicelog.pre <<EOF
getent group service >/dev/null || %{_sbindir}/groupadd -r service
EOF
%endif

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%if %{system_user_pkg}
install -m 0644 -D -t %{buildroot}%{_sysusersdir}/ %{SOURCE3}
%endif

%pre -f libservicelog.pre

%post    -n %{lname} -p /sbin/ldconfig
%postun  -n %{lname} -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS
%attr( 754, root, service ) %dir %{_localstatedir}/lib/servicelog
%attr( 644, root, service ) %{_localstatedir}/lib/servicelog/servicelog.db
%if %{system_user_pkg}
%{_sysusersdir}/system-group-service.conf
%endif

%files -n %{lname}
%{_libdir}/lib*.so.*

%files devel
%{_includedir}/servicelog-1
%{_libdir}/pkgconfig/servicelog-1.pc
%{_libdir}/*.so

%changelog
* Thu Oct 26 2023 Michal Suchanek <msuchanek@suse.com>
- Use sysuser-tools package instead of creating the group (bsc#1216613)
* Thu Jul 15 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic, has no effect with --disable-static.
- Replace PreReq with Requires(pre).
- Do not ignore error return from useradd.
* Thu Jul 15 2021 Michal Suchanek <msuchanek@suse.com>
- Update to version 1.1.19 (jsc#SLE-18189)
  - Fix segfault on servicelog_open() failure
  - New project location
* Mon Aug 28 2017 jloeser@suse.com
- version update to 1.1.18 (fate#322223, fate#326427)
  - Sqlite bind call validation
  - Added libservicelog test cases
  - Print machine serial number
  - Fixed few regression issues
- removed patches:
  * libservicelog-1.1.17-Fixes-fdopen-failure-issue-properly.patch
  * libservicelog-1.1.17-Print-machine-serial-number-in-v29-path.patch
* Thu Aug 10 2017 msuchanek@suse.com
- Machine serial number is not reported to Lpar for a SRC event
  (bsc#1053227)
  * libservicelog-1.1.17-Fixes-fdopen-failure-issue-properly.patch
  * libservicelog-1.1.17-Print-machine-serial-number-in-v29-path.patch
* Mon Mar 27 2017 jloeser@suse.com
- version update to 1.1.17 (fate#321443)
  - NULL check before calling strdup
  - Fixed various bugs
* Tue Mar 22 2016 jloeser@suse.com
- version update to 1.1.16 (FATE#319556)
  - see libservicelog-1.1.16/ChangeLog for changes
- removed patches:
  * libservicelog-printf_types.patch
* Thu Sep  4 2014 jengelh@inai.de
- baselibs.conf did not match with the shared library package
- Remove libservicelog-lib_version.patch, there is no reason
  provided to have it in the first place.
- Remove libservicelog-pkgconfig.patch; there is nothing wrong
  with -L${libdir} in .pc files.
- Remove dlopen hacks; the packages ppc64-diag and servicelog which
  OBS lists as dependants use no visible call to dlopen but do
  a compile-time link.
- As the public header servicelog.h #includes <sqlite3.h>,
  Reqiures: sqlite3-devel is needed for libservicelog-devel.
* Thu Sep  4 2014 jloeser@suse.com
- version update to 1.1.15 (BNC#894856)
  - Cleanup build tools (configure.ac and Makefile.am)
- modified patches:
  * libservicelog-lib_version.patch
  * libservicelog-pkgconfig.patch
* Fri Jan 17 2014 jloeser@suse.com
- version update to 1.1.14 (FATE#315456)
  include servicelog.db and bootstrap.sh file into compression file
  list
- Prereq: groupadd for %%post
* Tue Dec 10 2013 dvaleev@suse.com
- enable ppc64le
* Thu Mar 28 2013 dvaleev@suse.com
- update to 1.1.23
- Legalize SQL insert command input string
- Minor typo fix
- repair_action : fix output format issue
- drop libservicelog.install.patch
- refresh libservicelog-printf_types.patch
* Wed Dec  5 2012 dvaleev@suse.com
- update to 1.1.12
  Upstream changelog:
  Minor changes
- more printf types fixes (libservicelog-printf_types.patch)
* Thu Jun 28 2012 pth@suse.de
- Using both -version-info and -release options for libtool is bogus,
  therefore use version-info only and name shared library package
  accordingly.
- Adapt requires of -devel package.
* Tue Jan 31 2012 meissner@suse.de
- buildreq autoconf and libtool so autoreconf -ivf works again.
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Wed Nov  2 2011 dvaleev@suse.com
- update to 1.1.11
  - new build requires librtas-devel pkg-config
  - reworked patches
  - Drop libservicelog.warnings.patch,
  libservicelog.sqlite-include.patch
  libservicelog-sqlite_fixes.patch
  - Fix package description typo
  - ppc,ppc64 exclusive package as it is requires librtas
* Tue Apr 20 2010 dimstar@opensuse.org
- Fix build: use %%__rm instead of %%rm.
* Mon Apr 19 2010 pth@novell.com
- Fix .changes
* Wed Apr 14 2010 pth@novell.com
- Fix .pc file (bnc#588706)
- Only pass -L${libdir} if libdir isn't searched by default.
- Rename sqlite-fixes to libservicelog-sqlite_fixes.patch.
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Thu Dec 10 2009 duwe@suse.de
- Fix sqlite free()s and one insert statement (bnc#482351)
* Mon Jan 26 2009 crrodriguez@suse.de
- remove "la" files
* Wed Sep 10 2008 olh@suse.de
- link against sqlite3
* Fri Aug 29 2008 olh@suse.de
- new libservicelog-1.0.1, libservicelog-1_0-1 and libservicelog-devel
  packages (bnc#417533)
